.. _url_module:

:mod:`pyramid.url`
---------------------

.. automodule:: pyramid.url

  .. autofunction:: pyramid.url.resource_url(context, request, *elements, query=None, anchor=None)

  .. autofunction:: route_url

  .. autofunction:: current_route_url

  .. autofunction:: route_path

  .. autofunction:: current_route_path

  .. autofunction:: static_url

  .. autofunction:: static_path

  .. autofunction:: urlencode

